@@ -19,12 +19,12 @@
 # limitations under the License.
 #
 
-from . import __user_agent__
-from .exceptions import SessionException
+from .common import user_agent, SessionException
 
 from pyquery import PyQuery as pq
 
 import requests as rq
+import json
 import pandas as pd
 import urllib.parse
 
@@ -87,23 +87,13 @@ class HomeBrokerSession:
         """
 
         try:
-            headers = {
-                'User-Agent': __user_agent__,
-                'Accept-Encoding': 'gzip, deflate',
-                'Content-Type': 'application/x-www-form-urlencoded'
-            }
-
-            url = '{}/Login/Ingresar'.format(self.broker['page'])
-
-            payload = {
-                'IpAddress': self.__get_ipaddress(),
-                'Dni': dni,
-                'Usuario': user,
-                'Password': password}
-            payload = urllib.parse.urlencode(payload)
-
             with rq.Session() as sess:
-                response = sess.post(url, data=payload, headers=headers, proxies=self._proxies)
+
+                response = self.__perform_login_main(sess, dni, user, password)
+                
+                if response.status_code == 500: # Only check for Internal Server error to test the alternative login.  Otherwise, the error is valid.
+                    response = self.__perform_login_alternative(sess, dni, user, password)
+
                 response.raise_for_status()
 
                 doc = pq(response.text)
@@ -137,6 +127,52 @@ class HomeBrokerSession:
 #########################
 #### PRIVATE METHODS ####
 #########################
+    def __perform_login_main(self, sess, dni, user, password):
+        
+        headers = {
+            'User-Agent': user_agent,
+            'Accept-Encoding': 'gzip, deflate',
+            'Content-Type': 'application/x-www-form-urlencoded'
+        }
+
+        url = '{}/Login/Ingresar'.format(self.broker['page'])
+
+        payload = {
+            'IpAddress': self.__get_ipaddress(),
+            'Dni': dni,
+            'Usuario': user,
+            'Password': password}
+            
+        payload = urllib.parse.urlencode(payload)
+
+        sess.cookies.clear()
+        # Force to get the main page to retrieve any required cookie
+        sess.get(self.broker['page'], headers=headers, proxies=self._proxies)
+        return sess.post(url, data=payload, headers=headers, proxies=self._proxies)
+        
+    def __perform_login_alternative(self, sess, dni, user, password):
+        
+        headers = {
+            'User-Agent': user_agent,
+            'Accept-Encoding': 'gzip, deflate',
+            'Content-Type': 'application/json; charset=utf-8'
+        }
+
+        url = '{}/Login/IngresarModal'.format(self.broker['page'])
+
+        payload = {
+            'IpAddress': self.__get_ipaddress(),
+            'Dni': dni,
+            'Usuario': user,
+            'Password': password}
+            
+        payload = json.dumps(payload, separators=(',', ':'))
+        
+        sess.cookies.clear()
+        # Force to get the main page to retrieve any required cookie
+        sess.get(self.broker['page'], headers=headers, proxies=self._proxies)
+        return sess.post(url, data=payload, headers=headers, proxies=self._proxies)
+
     def __get_ipaddress(self):
 
         if not self.__ipaddress:
